@@ -1,10 +1,12 @@
+from logging import getLogger
+from typing import Optional
+
 from aiogram import Bot, Dispatcher
 from aiogram.types.base import TelegramObject
 
 from state_manager.models.dependencys.base import BaseDependencyStorage, back_to_pre_state_, BaseStateManager
 from state_manager.models.state import StateData
 from state_manager.types import Context, Data
-from logging import getLogger
 
 logger = getLogger(__name__)
 
@@ -21,23 +23,7 @@ class AiogramStateManager(BaseStateManager):
         logger.debug(f"back_to_pre_state, {data=}")
         await back_to_pre_state_(self.storage, self.context.from_user.id, data)
 
-    @property
-    async def data(self) -> Data:
-        return (await self._get_state_data()).data
-
-    @property
-    async def current_state(self) -> str:
-        return (await self._get_state_data()).current_state
-
-    @property
-    async def pre_state(self) -> str:
-        return (await self._get_state_data()).pre_state
-
-    @property
-    async def state_data(self) -> StateData:
-        return await self._get_state_data()
-
-    async def _get_state_data(self) -> StateData:
+    async def _get_state_data(self) -> Optional[StateData]:
         logger.debug(f"get_storage")
         return await self.storage.get(self.context.from_user.id)
 
@@ -49,6 +35,7 @@ class AiogramDependencyStorage(BaseDependencyStorage):
     bot: Bot
     dispatcher: Dispatcher
     context: TelegramObject
+    data: Optional[dict] = None
 
     class Config:
         arbitrary_types_allowed = True
